@@ -1376,7 +1376,10 @@ class Base_Page(Borg, unittest.TestCase):
         window = self.execute_javascript_with_return("window.innerHeight")
         if self.check_dom_element_is_display_on_screen_by_yaxis_and_js(element):
             return
-        cmd = "window.scrollBy(0, %s)" % str(y-(top+window)+(window/2))
+        if y > top:
+            cmd = "window.scrollBy(0, %s)" % str((y-top)-(window/2))
+        else:
+            cmd = "window.scrollBy(0, %s)" % str((top-y) - (window / 2))
         self.execute_javascript(cmd)
         self.wait(wait_time)
 
